/*
 * SourceMod Radio
 *
 * Adds a radio player to SourceMod that supports direct station links or streaming audio
 *
 * Coded by dubbeh - www.dubbeh.net
 *
 * Licensed under the GPLv3
 *
 */

public Handler_BaseRadioMenu(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	char szSelection[32] = "";
	
	if (maAction == MenuAction_Select) {
		mMenu.GetItem(iParam, szSelection, sizeof(szSelection));
		
		if (g_iRadioPlayType == RADIO_PLAY_TYPE_SHOUTCAST && g_bShoutCastCustom) {
			if (szSelection[0] == '1') {
				if (g_mRadioBaseGenresMenu != INVALID_HANDLE)
					g_mRadioBaseGenresMenu.Display(iClient, MENU_TIME_FOREVER);
				else
					SetFailState("[SM-RADIO] Base genres menu appears to be invalid. Please report this error to the author.");
			} else if (szSelection[0] == '2') {
				if (g_bCustUseGenres) {
					if (g_mRadioCustomBaseGenresMenu != INVALID_HANDLE)
						g_mRadioCustomBaseGenresMenu.Display(iClient, MENU_TIME_FOREVER);
					else
						SetFailState("[SM-RADIO] Custom base genres menu appears to be invalid. Please report this error to the author.");
				} else {
					if (g_mRadioCustomStationsMenu != INVALID_HANDLE)
						g_mRadioCustomStationsMenu.Display(iClient, MENU_TIME_FOREVER);
					else
						SetFailState("[SM-RADIO] Custom stations menu appears to be invalid. Please report this error to the author.");
				}
			} else if (szSelection[0] == '3') {
				if (g_mRadioVolumeMenu != INVALID_HANDLE)
					g_mRadioVolumeMenu.Display(iClient, MENU_TIME_FOREVER);
				else
					SetFailState("[SM-RADIO] Volume menu handle appears to be invalid. Please report this error the author.");
			} else if (szSelection[0] == '4') {
				LoadOffPage(iClient);
			}
		} else if (g_bUseGenres) {
			if (szSelection[0] == '1') {
				if (g_mRadioBaseGenresMenu != INVALID_HANDLE)
					g_mRadioBaseGenresMenu.Display(iClient, MENU_TIME_FOREVER);
				else
					SetFailState("[SM-RADIO] Base genres menu appears to be invalid. Please report this error to the author.");
			} else if (szSelection[0] == '2') {
				if (g_mRadioVolumeMenu != INVALID_HANDLE)
					g_mRadioVolumeMenu.Display(iClient, MENU_TIME_FOREVER);
				else
					SetFailState("[SM-RADIO] Volume menu handle appears to be invalid. Please report this error the author.");
			} else if (szSelection[0] == '3') {
				LoadOffPage(iClient);
			}
		} else {
			if (szSelection[0] == '1') {
				if (g_mRadioStationsMenu != INVALID_HANDLE)
					g_mRadioStationsMenu.Display(iClient, MENU_TIME_FOREVER);
				else
					SetFailState("[SM-RADIO] Station menu appears to be null. Please report this error to the author.");
				// Volume control is only added if Radio Type > RADIO_PLAY_TYPE_DIRECT
			} else if (szSelection[0] == '2') {
				if (g_mRadioVolumeMenu != INVALID_HANDLE)
					g_mRadioVolumeMenu.Display(iClient, MENU_TIME_FOREVER);
				else
					SetFailState("[SM-RADIO] Volume menu appears to be null. Please report this error to the author.");
			}
			else if (szSelection[0] == '3')
			{
				LoadOffPage(iClient);
			}
		}
	}
}

public Handler_SelectGenre(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	char szGenreID[12] = "";
	char szGenreName[64] = "";
	Genre genre;
	
	if (maAction == MenuAction_Cancel) {
		if (iParam == MenuCancel_ExitBack)
			g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
	} else if (maAction == MenuAction_Select) {
		mMenu.GetItem(iParam, szGenreID, sizeof(szGenreID));
		genre = g_Genres.Items(GetGenreIndexFromID(StringToInt(szGenreID)));
		
		if (genre.IsValid) {
			if (genre.m_hMenu != INVALID_HANDLE) {
				DisplayMenu(genre.m_hMenu, iClient, MENU_TIME_FOREVER);
			} else {
				genre.GetName(szGenreName, sizeof(szGenreName));
				SetFailState("[SM-RADIO] Error: Menu handle for genre \"%d\" appears to be invalid", szGenreName);
			}
		} else {
			SetFailState("[SM-RADIO] Error: Found an invalid Genre ID.");
		}
	}
}

public Handler_CustomSelectGenre(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	char szGenreID[12] = "";
	char szGenreName[64] = "";
	CustomGenre custgenre;
	
	if (maAction == MenuAction_Cancel) {
		if (iParam == MenuCancel_ExitBack)
			g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
	} else if (maAction == MenuAction_Select) {
		mMenu.GetItem(iParam, szGenreID, sizeof(szGenreID));
		custgenre = g_CustGenres.Items(GetCustomGenreIndexFromID(StringToInt(szGenreID)));
		
		if (custgenre.IsValid) {
			if (custgenre.m_hMenu != INVALID_HANDLE) {
				DisplayMenu(custgenre.m_hMenu, iClient, MENU_TIME_FOREVER);
			} else {
				custgenre.GetName(szGenreName, sizeof(szGenreName));
				SetFailState("[SM-RADIO] Error: Menu handle for custom genre \"%d\" appears to be invalid", szGenreName);
			}
		} else {
			SetFailState("[SM-RADIO] Error: Found an invalid Genre ID.");
		}
	}
}

public Handler_PlayRadioStation(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	char szRadioStationID[16] = "";
	
	if (maAction == MenuAction_Cancel) {
		if (iParam == MenuCancel_ExitBack) {
			if (g_bUseGenres)
				g_mRadioBaseGenresMenu.Display(iClient, MENU_TIME_FOREVER);
			else
				g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
		}
	} else if (maAction == MenuAction_Select) {
		mMenu.GetItem(iParam, szRadioStationID, sizeof(szRadioStationID));
		LoadStation(iClient, szRadioStationID, false);
	}
}

public Handler_CustomPlayRadioStation(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	char szRadioStationID[16] = "";
	
	if (maAction == MenuAction_Cancel) {
		if (iParam == MenuCancel_ExitBack) {
			if (g_bCustUseGenres)
				g_mRadioCustomBaseGenresMenu.Display(iClient, MENU_TIME_FOREVER);
			else
				g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
		}
	} else if (maAction == MenuAction_Select) {
		mMenu.GetItem(iParam, szRadioStationID, sizeof(szRadioStationID));
		LoadStation(iClient, szRadioStationID, true);
	}
}

public Handler_VolumeMenu(Menu mMenu, MenuAction maAction, int iClient, int iParam)
{
	char szStationID[32] = "";
	char szStationVolume[32] = "";
	char szIsCustomShoutCast[8] = "";
	
	if (maAction == MenuAction_Cancel) {
		if (iParam == MenuCancel_ExitBack)
			g_mRadioBaseMenu.Display(iClient, MENU_TIME_FOREVER);
	} else if (maAction == MenuAction_Select) {
		mMenu.GetItem(iParam, szStationVolume, sizeof(szStationVolume));
		SetClientCookie(iClient, g_hCookieSavedVolume, szStationVolume);
		CPrintToChat(iClient, "%T", "Volume Set To", LANG_SERVER, szStationVolume);
		GetClientCookie(iClient, g_hCookieSavedStation, szStationID, sizeof(szStationID));
		
		if (szStationID[0]) {
			GetClientCookie(iClient, g_hCookieCustomShoutCast, szIsCustomShoutCast, sizeof(szIsCustomShoutCast));
			LoadStation(iClient, szStationID, view_as<bool>(StringToInt(szIsCustomShoutCast)));
		}
	}
}
